@@ -20,16 +20,14 @@
 
 use crate::{
     error::Result,
-    execution::{
-        disk_manager::{DiskManager, DiskManagerConfig},
-        memory_manager::{MemoryConsumerId, MemoryManager, MemoryManagerConfig},
-    },
+    execution::disk_manager::{DiskManager, DiskManagerConfig},
 };
 use std::collections::HashMap;
 
 use crate::datasource::datasource::TableProviderFactory;
 use crate::datasource::listing_table_factory::ListingTableFactory;
 use crate::datasource::object_store::ObjectStoreRegistry;
+use crate::execution::memory_pool::{GreedyMemoryPool, MemoryPool, UnboundedMemoryPool};
 use datafusion_common::DataFusionError;
 use object_store::ObjectStore;
 use std::fmt::{Debug, Formatter};
@@ -41,7 +39,7 @@ use url::Url;
 /// Execution runtime environment.
 pub struct RuntimeEnv {
     /// Runtime memory management
-    pub memory_manager: Arc<MemoryManager>,
+    pub memory_pool: Arc<dyn MemoryPool>,
     /// Manage temporary files during query execution
     pub disk_manager: Arc<DiskManager>,
     /// Object Store Registry
@@ -60,40 +58,23 @@ impl RuntimeEnv {
     /// Create env based on configuration
     pub fn new(config: RuntimeConfig) -> Result<Self> {
         let RuntimeConfig {
-            memory_manager,
+            memory_pool,
             disk_manager,
             object_store_registry,
             table_factories,
         } = config;
 
+        let memory_pool =
+            memory_pool.unwrap_or_else(|| Arc::new(UnboundedMemoryPool::default()));
+
         Ok(Self {
-            memory_manager: MemoryManager::new(memory_manager),
+            memory_pool,
             disk_manager: DiskManager::try_new(disk_manager)?,
             object_store_registry,
             table_factories,
         })
     }
 
-    /// Register the consumer to get it tracked
-    pub fn register_requester(&self, id: &MemoryConsumerId) {
-        self.memory_manager.register_requester(id);
-    }
-
-    /// Drop the consumer from get tracked, reclaim memory
-    pub fn drop_consumer(&self, id: &MemoryConsumerId, mem_used: usize) {
-        self.memory_manager.drop_consumer(id, mem_used)
-    }
-
-    /// Grow tracker memory of `delta`
-    pub fn grow_tracker_usage(&self, delta: usize) {
-        self.memory_manager.grow_tracker_usage(delta)
-    }
-
-    /// Shrink tracker memory of `delta`
-    pub fn shrink_tracker_usage(&self, delta: usize) {
-        self.memory_manager.shrink_tracker_usage(delta)
-    }
-
     /// Registers a custom `ObjectStore` to be used when accessing a
     /// specific scheme and host. This allows DataFusion to create
     /// external tables from urls that do not have built in support
@@ -142,8 +123,10 @@ impl Default for RuntimeEnv {
 pub struct RuntimeConfig {
     /// DiskManager to manage temporary disk file usage
     pub disk_manager: DiskManagerConfig,
-    /// MemoryManager to limit access to memory
-    pub memory_manager: MemoryManagerConfig,
+    /// [`MemoryPool`] from which to allocate memory
+    ///
+    /// Defaults to using an [`UnboundedMemoryPool`] if `None`
+    pub memory_pool: Option<Arc<dyn MemoryPool>>,
     /// ObjectStoreRegistry to get object store based on url
     pub object_store_registry: Arc<ObjectStoreRegistry>,
     /// Custom table factories for things like deltalake that are not part of core datafusion
@@ -172,9 +155,9 @@ impl RuntimeConfig {
         self
     }
 
-    /// Customize memory manager
-    pub fn with_memory_manager(mut self, memory_manager: MemoryManagerConfig) -> Self {
-        self.memory_manager = memory_manager;
+    /// Customize memory policy
+    pub fn with_memory_pool(mut self, memory_pool: Arc<dyn MemoryPool>) -> Self {
+        self.memory_pool = Some(memory_pool);
         self
     }
 
@@ -199,11 +182,12 @@ impl RuntimeConfig {
     /// Specify the total memory to use while running the DataFusion
     /// plan to `max_memory * memory_fraction` in bytes.
     ///
+    /// This defaults to using [`GreedyMemoryPool`]
+    ///
     /// Note DataFusion does not yet respect this limit in all cases.
     pub fn with_memory_limit(self, max_memory: usize, memory_fraction: f64) -> Self {
-        self.with_memory_manager(
-            MemoryManagerConfig::try_new_limit(max_memory, memory_fraction).unwrap(),
-        )
+        let pool_size = (max_memory as f64 * memory_fraction) as usize;
+        self.with_memory_pool(Arc::new(GreedyMemoryPool::new(pool_size)))
     }
 
     /// Use the specified path to create any needed temporary files
