@@ -1925,31 +1925,31 @@ mod tests {
                     vec![
                         top_join_plan.as_str(),
                         join_plan.as_str(),
-                        "SortExec: [a@0 ASC]",
+                        "SortExec: expr=[a@0 ASC]",
                         "RepartitionExec: partitioning=Hash([Column { name: \"a\", index: 0 }], 10), input_partitions=1",
                         "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
-                        "SortExec: [b1@1 ASC]",
+                        "SortExec: expr=[b1@1 ASC]",
                         "RepartitionExec: partitioning=Hash([Column { name: \"b1\", index: 1 }], 10), input_partitions=1",
                         "ProjectionExec: expr=[a@0 as a1, b@1 as b1, c@2 as c1, d@3 as d1, e@4 as e1]",
                         "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
-                        "SortExec: [c@2 ASC]",
+                        "SortExec: expr=[c@2 ASC]",
                         "RepartitionExec: partitioning=Hash([Column { name: \"c\", index: 2 }], 10), input_partitions=1",
                         "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
                     ],
                 // Should include 4 RepartitionExecs
                 _ => vec![
                         top_join_plan.as_str(),
-                        "SortExec: [a@0 ASC]",
+                        "SortExec: expr=[a@0 ASC]",
                         "RepartitionExec: partitioning=Hash([Column { name: \"a\", index: 0 }], 10), input_partitions=10",
                         join_plan.as_str(),
-                        "SortExec: [a@0 ASC]",
+                        "SortExec: expr=[a@0 ASC]",
                         "RepartitionExec: partitioning=Hash([Column { name: \"a\", index: 0 }], 10), input_partitions=1",
                         "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
-                        "SortExec: [b1@1 ASC]",
+                        "SortExec: expr=[b1@1 ASC]",
                         "RepartitionExec: partitioning=Hash([Column { name: \"b1\", index: 1 }], 10), input_partitions=1",
                         "ProjectionExec: expr=[a@0 as a1, b@1 as b1, c@2 as c1, d@3 as d1, e@4 as e1]",
                         "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
-                        "SortExec: [c@2 ASC]",
+                        "SortExec: expr=[c@2 ASC]",
                         "RepartitionExec: partitioning=Hash([Column { name: \"c\", index: 2 }], 10), input_partitions=1",
                         "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
                 ],
@@ -1978,31 +1978,31 @@ mod tests {
                         JoinType::Inner | JoinType::Right => vec![
                             top_join_plan.as_str(),
                             join_plan.as_str(),
-                            "SortExec: [a@0 ASC]",
+                            "SortExec: expr=[a@0 ASC]",
                             "RepartitionExec: partitioning=Hash([Column { name: \"a\", index: 0 }], 10), input_partitions=1",
                             "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
-                            "SortExec: [b1@1 ASC]",
+                            "SortExec: expr=[b1@1 ASC]",
                             "RepartitionExec: partitioning=Hash([Column { name: \"b1\", index: 1 }], 10), input_partitions=1",
                             "ProjectionExec: expr=[a@0 as a1, b@1 as b1, c@2 as c1, d@3 as d1, e@4 as e1]",
                             "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
-                            "SortExec: [c@2 ASC]",
+                            "SortExec: expr=[c@2 ASC]",
                             "RepartitionExec: partitioning=Hash([Column { name: \"c\", index: 2 }], 10), input_partitions=1",
                             "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
                         ],
                         // Should include 4 RepartitionExecs and 4 SortExecs
                         _ => vec![
                             top_join_plan.as_str(),
-                            "SortExec: [b1@6 ASC]",
+                            "SortExec: expr=[b1@6 ASC]",
                             "RepartitionExec: partitioning=Hash([Column { name: \"b1\", index: 6 }], 10), input_partitions=10",
                             join_plan.as_str(),
-                            "SortExec: [a@0 ASC]",
+                            "SortExec: expr=[a@0 ASC]",
                             "RepartitionExec: partitioning=Hash([Column { name: \"a\", index: 0 }], 10), input_partitions=1",
                             "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
-                            "SortExec: [b1@1 ASC]",
+                            "SortExec: expr=[b1@1 ASC]",
                             "RepartitionExec: partitioning=Hash([Column { name: \"b1\", index: 1 }], 10), input_partitions=1",
                             "ProjectionExec: expr=[a@0 as a1, b@1 as b1, c@2 as c1, d@3 as d1, e@4 as e1]",
                             "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
-                            "SortExec: [c@2 ASC]",
+                            "SortExec: expr=[c@2 ASC]",
                             "RepartitionExec: partitioning=Hash([Column { name: \"c\", index: 2 }], 10), input_partitions=1",
                             "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
                         ],
@@ -2065,14 +2065,14 @@ mod tests {
         // Only two RepartitionExecs added
         let expected = &[
             "SortMergeJoin: join_type=Inner, on=[(Column { name: \"b3\", index: 1 }, Column { name: \"b2\", index: 1 }), (Column { name: \"a3\", index: 0 }, Column { name: \"a2\", index: 0 })]",
-            "SortExec: [b3@1 ASC,a3@0 ASC]",
+            "SortExec: expr=[b3@1 ASC,a3@0 ASC]",
             "ProjectionExec: expr=[a1@0 as a3, b1@1 as b3]",
             "ProjectionExec: expr=[a1@1 as a1, b1@0 as b1]",
             "AggregateExec: mode=FinalPartitioned, gby=[b1@0 as b1, a1@1 as a1], aggr=[]",
             "RepartitionExec: partitioning=Hash([Column { name: \"b1\", index: 0 }, Column { name: \"a1\", index: 1 }], 10), input_partitions=1",
             "AggregateExec: mode=Partial, gby=[b@1 as b1, a@0 as a1], aggr=[]",
             "ParquetExec: limit=None, partitions={1 group: [[x]]}, projection=[a, b, c, d, e]",
-            "SortExec: [b2@1 ASC,a2@0 ASC]",
+            "SortExec: expr=[b2@1 ASC,a2@0 ASC]",
             "ProjectionExec: expr=[a@1 as a2, b@0 as b2]",
             "AggregateExec: mode=FinalPartitioned, gby=[b@0 as b, a@1 as a], aggr=[]",
             "RepartitionExec: partitioning=Hash([Column { name: \"b\", index: 0 }, Column { name: \"a\", index: 1 }], 10), input_partitions=1",
