@@ -139,6 +139,10 @@ impl PagePruningPredicate {
         let page_index_predicates = &self.predicates;
         let groups = file_metadata.row_groups();
 
+        if groups.is_empty() {
+            return Ok(None);
+        }
+
         let file_offset_indexes = file_metadata.offset_indexes();
         let file_page_indexes = file_metadata.page_indexes();
         let (file_offset_indexes, file_page_indexes) =
@@ -155,30 +159,25 @@ impl PagePruningPredicate {
 
         let mut row_selections = Vec::with_capacity(page_index_predicates.len());
         for predicate in page_index_predicates {
-            // `extract_page_index_push_down_predicates` only return predicate with one col.
-            //  when building `PruningPredicate`, some single column filter like `abs(i) = 1`
-            //  will be rewrite to `lit(true)`, so may have an empty required_columns.
-            let col_id =
-                if let Some(&col_id) = predicate.need_input_columns_ids().iter().next() {
-                    col_id
-                } else {
-                    continue;
-                };
+            // find column index by looking in the row group metadata.
+            let col_idx = find_column_index(predicate, &groups[0]);
 
             let mut selectors = Vec::with_capacity(row_groups.len());
             for r in row_groups.iter() {
+                let row_group_metadata = &groups[*r];
+
                 let rg_offset_indexes = file_offset_indexes.get(*r);
                 let rg_page_indexes = file_page_indexes.get(*r);
-                if let (Some(rg_page_indexes), Some(rg_offset_indexes)) =
-                    (rg_page_indexes, rg_offset_indexes)
+                if let (Some(rg_page_indexes), Some(rg_offset_indexes), Some(col_idx)) =
+                    (rg_page_indexes, rg_offset_indexes, col_idx)
                 {
                     selectors.extend(
                         prune_pages_in_one_row_group(
-                            &groups[*r],
+                            row_group_metadata,
                             predicate,
-                            rg_offset_indexes.get(col_id),
-                            rg_page_indexes.get(col_id),
-                            groups[*r].column(col_id).column_descr(),
+                            rg_offset_indexes.get(col_idx),
+                            rg_page_indexes.get(col_idx),
+                            groups[*r].column(col_idx).column_descr(),
                             file_metrics,
                         )
                         .map_err(|e| {
@@ -190,7 +189,7 @@ impl PagePruningPredicate {
                 } else {
                     trace!(
                         "Did not have enough metadata to prune with page indexes, \
-                         falling back, falling back to all rows",
+                         falling back to all rows",
                     );
                     // fallback select all rows
                     let all_selected =
@@ -223,6 +222,64 @@ impl PagePruningPredicate {
     }
 }
 
+/// Returns the column index in the row group metadata for the single
+/// column of a single column pruning predicate.
+///
+/// For example, give the predicate `y > 5`
+///
+/// And columns in the RowGroupMetadata like `['x', 'y', 'z']` will
+/// return 1.
+///
+/// Returns `None` if the column is not found, or if there are no
+/// required columns, which is the case for predicate like `abs(i) =
+/// 1` which are rewritten to `lit(true)`
+///
+/// Panics:
+///
+/// If the predicate contains more than one column reference (assumes
+/// that `extract_page_index_push_down_predicates` only return
+/// predicate with one col)
+///
+fn find_column_index(
+    predicate: &PruningPredicate,
+    row_group_metadata: &RowGroupMetaData,
+) -> Option<usize> {
+    let mut found_required_column: Option<&Column> = None;
+
+    for required_column_details in predicate.required_columns().iter() {
+        let column = &required_column_details.0;
+        if let Some(found_required_column) = found_required_column.as_ref() {
+            // make sure it is the same name we have seen previously
+            assert_eq!(
+                column.name, found_required_column.name,
+                "Unexpected multi column predicate"
+            );
+        } else {
+            found_required_column = Some(column);
+        }
+    }
+
+    let column = if let Some(found_required_column) = found_required_column.as_ref() {
+        found_required_column
+    } else {
+        trace!("No column references in pruning predicate");
+        return None;
+    };
+
+    let col_idx = row_group_metadata
+        .columns()
+        .iter()
+        .enumerate()
+        .find(|(_idx, c)| c.column_descr().name() == column.name)
+        .map(|(idx, _c)| idx);
+
+    if col_idx.is_none() {
+        trace!("Can not find column {} in row group meta", column.name);
+    }
+
+    col_idx
+}
+
 /// Intersects the [`RowSelector`]s
 ///
 /// For exampe, given:
