@@ -127,6 +127,82 @@ async fn sort_on_unprojected_columns() -> Result<()> {
     Ok(())
 }
 
+#[tokio::test]
+async fn sort_on_distinct_columns() -> Result<()> {
+    let schema = Schema::new(vec![
+        Field::new("a", DataType::Int32, false),
+        Field::new("b", DataType::Int32, false),
+    ]);
+
+    let batch = RecordBatch::try_new(
+        Arc::new(schema.clone()),
+        vec![
+            Arc::new(Int32Array::from_slice([1, 10, 10, 100])),
+            Arc::new(Int32Array::from_slice([2, 3, 4, 5])),
+        ],
+    )
+    .unwrap();
+
+    let ctx = SessionContext::new();
+    ctx.register_batch("t", batch).unwrap();
+    let df = ctx
+        .table("t")
+        .await
+        .unwrap()
+        .select(vec![col("a")])
+        .unwrap()
+        .distinct()
+        .unwrap()
+        .sort(vec![Expr::Sort(Sort::new(Box::new(col("a")), false, true))])
+        .unwrap();
+    let results = df.collect().await.unwrap();
+
+    #[rustfmt::skip]
+    let expected = vec![
+        "+-----+",
+        "| a   |",
+        "+-----+",
+        "| 100 |",
+        "| 10  |",
+        "| 1   |",
+        "+-----+",
+    ];
+    assert_batches_eq!(expected, &results);
+    Ok(())
+}
+#[tokio::test]
+async fn sort_on_distinct_unprojected_columns() -> Result<()> {
+    let schema = Schema::new(vec![
+        Field::new("a", DataType::Int32, false),
+        Field::new("b", DataType::Int32, false),
+    ]);
+
+    let batch = RecordBatch::try_new(
+        Arc::new(schema.clone()),
+        vec![
+            Arc::new(Int32Array::from_slice([1, 10, 10, 100])),
+            Arc::new(Int32Array::from_slice([2, 3, 4, 5])),
+        ],
+    )
+    .unwrap();
+
+    // Cannot sort on a column after distinct that would add a new column
+    let ctx = SessionContext::new();
+    ctx.register_batch("t", batch).unwrap();
+    let err = ctx
+        .table("t")
+        .await
+        .unwrap()
+        .select(vec![col("a")])
+        .unwrap()
+        .distinct()
+        .unwrap()
+        .sort(vec![Expr::Sort(Sort::new(Box::new(col("b")), false, true))])
+        .unwrap_err();
+    assert_eq!(err.to_string(), "Error during planning: For SELECT DISTINCT, ORDER BY expressions b must appear in select list");
+    Ok(())
+}
+
 #[tokio::test]
 async fn filter_with_alias_overwrite() -> Result<()> {
     let schema = Schema::new(vec![Field::new("a", DataType::Int32, false)]);
@@ -171,24 +247,19 @@ async fn select_with_alias_overwrite() -> Result<()> {
     let batch = RecordBatch::try_new(
         Arc::new(schema.clone()),
         vec![Arc::new(Int32Array::from_slice([1, 10, 10, 100]))],
-    )
-    .unwrap();
+    )?;
 
     let ctx = SessionContext::new();
     ctx.register_batch("t", batch).unwrap();
 
     let df = ctx
         .table("t")
-        .await
-        .unwrap()
-        .select(vec![col("a").alias("a")])
-        .unwrap()
-        .select(vec![(col("a").eq(lit(10))).alias("a")])
-        .unwrap()
-        .select(vec![col("a")])
-        .unwrap();
+        .await?
+        .select(vec![col("a").alias("a")])?
+        .select(vec![(col("a").eq(lit(10))).alias("a")])?
+        .select(vec![col("a")])?;
 
-    let results = df.collect().await.unwrap();
+    let results = df.collect().await?;
 
     #[rustfmt::skip]
         let expected = vec![
@@ -322,19 +393,19 @@ async fn test_grouping_set_array_agg_with_overflow() -> Result<()> {
         "|    | 2  | 184    | 8.363636363636363   |",
         "|    | 1  | 367    | 16.681818181818183  |",
         "| e  |    | 847    | 40.333333333333336  |",
-        "| e  | 5  | -22    | -11                 |",
+        "| e  | 5  | -22    | -11.0               |",
         "| e  | 4  | 261    | 37.285714285714285  |",
-        "| e  | 3  | 192    | 48                  |",
+        "| e  | 3  | 192    | 48.0                |",
         "| e  | 2  | 189    | 37.8                |",
         "| e  | 1  | 227    | 75.66666666666667   |",
         "| d  |    | 458    | 25.444444444444443  |",
         "| d  | 5  | -99    | -49.5               |",
-        "| d  | 4  | 162    | 54                  |",
+        "| d  | 4  | 162    | 54.0                |",
         "| d  | 3  | 124    | 41.333333333333336  |",
         "| d  | 2  | 328    | 109.33333333333333  |",
         "| d  | 1  | -57    | -8.142857142857142  |",
         "| c  |    | -28    | -1.3333333333333333 |",
-        "| c  | 5  | 24     | 12                  |",
+        "| c  | 5  | 24     | 12.0                |",
         "| c  | 4  | -43    | -10.75              |",
         "| c  | 3  | 190    | 47.5                |",
         "| c  | 2  | -389   | -55.57142857142857  |",
@@ -342,12 +413,12 @@ async fn test_grouping_set_array_agg_with_overflow() -> Result<()> {
         "| b  |    | -111   | -5.842105263157895  |",
         "| b  | 5  | -1     | -0.2                |",
         "| b  | 4  | -223   | -44.6               |",
-        "| b  | 3  | -84    | -42                 |",
+        "| b  | 3  | -84    | -42.0               |",
         "| b  | 2  | 102    | 25.5                |",
         "| b  | 1  | 95     | 31.666666666666668  |",
         "| a  |    | -385   | -18.333333333333332 |",
-        "| a  | 5  | -96    | -32                 |",
-        "| a  | 4  | -128   | -32                 |",
+        "| a  | 5  | -96    | -32.0               |",
+        "| a  | 4  | -128   | -32.0               |",
         "| a  | 3  | -27    | -4.5                |",
         "| a  | 2  | -46    | -15.333333333333334 |",
         "| a  | 1  | -88    | -17.6               |",
@@ -509,14 +580,14 @@ async fn unnest_columns() -> Result<()> {
     let df = table_with_nested_types(NUM_ROWS).await?;
     let results = df.collect().await?;
     let expected = vec![
-        r#"+----------+------------------------------------------------------------+--------------------+"#,
-        r#"| shape_id | points                                                     | tags               |"#,
-        r#"+----------+------------------------------------------------------------+--------------------+"#,
-        r#"| 1        | [{"x": -3, "y": -4}, {"x": -3, "y": 6}, {"x": 2, "y": -2}] | [tag1]             |"#,
-        r#"| 2        |                                                            | [tag1, tag2]       |"#,
-        r#"| 3        | [{"x": -9, "y": 2}, {"x": -10, "y": -4}]                   |                    |"#,
-        r#"| 4        | [{"x": -3, "y": 5}, {"x": 2, "y": -1}]                     | [tag1, tag2, tag3] |"#,
-        r#"+----------+------------------------------------------------------------+--------------------+"#,
+        "+----------+------------------------------------------------+--------------------+",
+        "| shape_id | points                                         | tags               |",
+        "+----------+------------------------------------------------+--------------------+",
+        "| 1        | [{x: -3, y: -4}, {x: -3, y: 6}, {x: 2, y: -2}] | [tag1]             |",
+        "| 2        |                                                | [tag1, tag2]       |",
+        "| 3        | [{x: -9, y: 2}, {x: -10, y: -4}]               |                    |",
+        "| 4        | [{x: -3, y: 5}, {x: 2, y: -1}]                 | [tag1, tag2, tag3] |",
+        "+----------+------------------------------------------------+--------------------+",
     ];
     assert_batches_sorted_eq!(expected, &results);
 
@@ -524,17 +595,17 @@ async fn unnest_columns() -> Result<()> {
     let df = table_with_nested_types(NUM_ROWS).await?;
     let results = df.unnest_column("tags")?.collect().await?;
     let expected = vec![
-        r#"+----------+------------------------------------------------------------+------+"#,
-        r#"| shape_id | points                                                     | tags |"#,
-        r#"+----------+------------------------------------------------------------+------+"#,
-        r#"| 1        | [{"x": -3, "y": -4}, {"x": -3, "y": 6}, {"x": 2, "y": -2}] | tag1 |"#,
-        r#"| 2        |                                                            | tag1 |"#,
-        r#"| 2        |                                                            | tag2 |"#,
-        r#"| 3        | [{"x": -9, "y": 2}, {"x": -10, "y": -4}]                   |      |"#,
-        r#"| 4        | [{"x": -3, "y": 5}, {"x": 2, "y": -1}]                     | tag1 |"#,
-        r#"| 4        | [{"x": -3, "y": 5}, {"x": 2, "y": -1}]                     | tag2 |"#,
-        r#"| 4        | [{"x": -3, "y": 5}, {"x": 2, "y": -1}]                     | tag3 |"#,
-        r#"+----------+------------------------------------------------------------+------+"#,
+        "+----------+------------------------------------------------+------+",
+        "| shape_id | points                                         | tags |",
+        "+----------+------------------------------------------------+------+",
+        "| 1        | [{x: -3, y: -4}, {x: -3, y: 6}, {x: 2, y: -2}] | tag1 |",
+        "| 2        |                                                | tag1 |",
+        "| 2        |                                                | tag2 |",
+        "| 3        | [{x: -9, y: 2}, {x: -10, y: -4}]               |      |",
+        "| 4        | [{x: -3, y: 5}, {x: 2, y: -1}]                 | tag1 |",
+        "| 4        | [{x: -3, y: 5}, {x: 2, y: -1}]                 | tag2 |",
+        "| 4        | [{x: -3, y: 5}, {x: 2, y: -1}]                 | tag3 |",
+        "+----------+------------------------------------------------+------+",
     ];
     assert_batches_sorted_eq!(expected, &results);
 
@@ -547,18 +618,18 @@ async fn unnest_columns() -> Result<()> {
     let df = table_with_nested_types(NUM_ROWS).await?;
     let results = df.unnest_column("points")?.collect().await?;
     let expected = vec![
-        r#"+----------+---------------------+--------------------+"#,
-        r#"| shape_id | points              | tags               |"#,
-        r#"+----------+---------------------+--------------------+"#,
-        r#"| 1        | {"x": -3, "y": -4}  | [tag1]             |"#,
-        r#"| 1        | {"x": -3, "y": 6}   | [tag1]             |"#,
-        r#"| 1        | {"x": 2, "y": -2}   | [tag1]             |"#,
-        r#"| 2        |                     | [tag1, tag2]       |"#,
-        r#"| 3        | {"x": -9, "y": 2}   |                    |"#,
-        r#"| 3        | {"x": -10, "y": -4} |                    |"#,
-        r#"| 4        | {"x": -3, "y": 5}   | [tag1, tag2, tag3] |"#,
-        r#"| 4        | {"x": 2, "y": -1}   | [tag1, tag2, tag3] |"#,
-        r#"+----------+---------------------+--------------------+"#,
+        "+----------+-----------------+--------------------+",
+        "| shape_id | points          | tags               |",
+        "+----------+-----------------+--------------------+",
+        "| 1        | {x: -3, y: -4}  | [tag1]             |",
+        "| 1        | {x: -3, y: 6}   | [tag1]             |",
+        "| 1        | {x: 2, y: -2}   | [tag1]             |",
+        "| 2        |                 | [tag1, tag2]       |",
+        "| 3        | {x: -10, y: -4} |                    |",
+        "| 3        | {x: -9, y: 2}   |                    |",
+        "| 4        | {x: -3, y: 5}   | [tag1, tag2, tag3] |",
+        "| 4        | {x: 2, y: -1}   | [tag1, tag2, tag3] |",
+        "+----------+-----------------+--------------------+",
     ];
     assert_batches_sorted_eq!(expected, &results);
 
@@ -575,23 +646,23 @@ async fn unnest_columns() -> Result<()> {
         .collect()
         .await?;
     let expected = vec![
-        r#"+----------+---------------------+------+"#,
-        r#"| shape_id | points              | tags |"#,
-        r#"+----------+---------------------+------+"#,
-        r#"| 1        | {"x": -3, "y": -4}  | tag1 |"#,
-        r#"| 1        | {"x": -3, "y": 6}   | tag1 |"#,
-        r#"| 1        | {"x": 2, "y": -2}   | tag1 |"#,
-        r#"| 2        |                     | tag1 |"#,
-        r#"| 2        |                     | tag2 |"#,
-        r#"| 3        | {"x": -9, "y": 2}   |      |"#,
-        r#"| 3        | {"x": -10, "y": -4} |      |"#,
-        r#"| 4        | {"x": -3, "y": 5}   | tag1 |"#,
-        r#"| 4        | {"x": -3, "y": 5}   | tag2 |"#,
-        r#"| 4        | {"x": -3, "y": 5}   | tag3 |"#,
-        r#"| 4        | {"x": 2, "y": -1}   | tag1 |"#,
-        r#"| 4        | {"x": 2, "y": -1}   | tag2 |"#,
-        r#"| 4        | {"x": 2, "y": -1}   | tag3 |"#,
-        r#"+----------+---------------------+------+"#,
+        "+----------+-----------------+------+",
+        "| shape_id | points          | tags |",
+        "+----------+-----------------+------+",
+        "| 1        | {x: -3, y: -4}  | tag1 |",
+        "| 1        | {x: -3, y: 6}   | tag1 |",
+        "| 1        | {x: 2, y: -2}   | tag1 |",
+        "| 2        |                 | tag1 |",
+        "| 2        |                 | tag2 |",
+        "| 3        | {x: -10, y: -4} |      |",
+        "| 3        | {x: -9, y: 2}   |      |",
+        "| 4        | {x: -3, y: 5}   | tag1 |",
+        "| 4        | {x: -3, y: 5}   | tag2 |",
+        "| 4        | {x: -3, y: 5}   | tag3 |",
+        "| 4        | {x: 2, y: -1}   | tag1 |",
+        "| 4        | {x: 2, y: -1}   | tag2 |",
+        "| 4        | {x: 2, y: -1}   | tag3 |",
+        "+----------+-----------------+------+",
     ];
     assert_batches_sorted_eq!(expected, &results);
 
@@ -607,6 +678,43 @@ async fn unnest_columns() -> Result<()> {
     Ok(())
 }
 
+#[tokio::test]
+async fn unnest_aggregate_columns() -> Result<()> {
+    const NUM_ROWS: usize = 5;
+
+    let df = table_with_nested_types(NUM_ROWS).await?;
+    let results = df.select_columns(&["tags"])?.collect().await?;
+    let expected = vec![
+        r#"+--------------------+"#,
+        r#"| tags               |"#,
+        r#"+--------------------+"#,
+        r#"| [tag1]             |"#,
+        r#"| [tag1, tag2]       |"#,
+        r#"|                    |"#,
+        r#"| [tag1, tag2, tag3] |"#,
+        r#"| [tag1, tag2, tag3] |"#,
+        r#"+--------------------+"#,
+    ];
+    assert_batches_sorted_eq!(expected, &results);
+
+    let df = table_with_nested_types(NUM_ROWS).await?;
+    let results = df
+        .unnest_column("tags")?
+        .aggregate(vec![], vec![count(col("tags"))])?
+        .collect()
+        .await?;
+    let expected = vec![
+        r#"+--------------------+"#,
+        r#"| COUNT(shapes.tags) |"#,
+        r#"+--------------------+"#,
+        r#"| 9                  |"#,
+        r#"+--------------------+"#,
+    ];
+    assert_batches_sorted_eq!(expected, &results);
+
+    Ok(())
+}
+
 async fn create_test_table() -> Result<DataFrame> {
     let schema = Arc::new(Schema::new(vec![
         Field::new("a", DataType::Utf8, false),
