@@ -662,10 +662,10 @@ async fn test_cast() -> Result<()> {
         "+--------+",
         "| test.b |",
         "+--------+",
-        "| 1      |",
-        "| 10     |",
-        "| 10     |",
-        "| 100    |",
+        "| 1.0    |",
+        "| 10.0   |",
+        "| 10.0   |",
+        "| 100.0  |",
         "+--------+",
     ];
 
