@@ -33,16 +33,16 @@ async fn json_query() {
         "+-----------------+------+",
         "| a               | b    |",
         "+-----------------+------+",
-        "| 1               | 2    |",
+        "| 1               | 2.0  |",
         "| -10             | -3.5 |",
         "| 2               | 0.6  |",
-        "| 1               | 2    |",
+        "| 1               | 2.0  |",
         "| 7               | -3.5 |",
         "| 1               | 0.6  |",
-        "| 1               | 2    |",
+        "| 1               | 2.0  |",
         "| 5               | -3.5 |",
         "| 1               | 0.6  |",
-        "| 1               | 2    |",
+        "| 1               | 2.0  |",
         "| 1               | -3.5 |",
         "| 100000000000000 | 0.6  |",
         "+-----------------+------+",
