@@ -44,11 +44,11 @@ async fn test_udf_returning_struct() {
     let ctx = udaf_struct_context();
     let sql = "SELECT first(value, time) from t";
     let expected = vec![
-        "+--------------------------------------------------+",
-        "| first(t.value,t.time)                            |",
-        "+--------------------------------------------------+",
-        "| {\"value\": 2, \"time\": 1970-01-01T00:00:00.000002} |",
-        "+--------------------------------------------------+",
+        "+------------------------------------------------+",
+        "| first(t.value,t.time)                          |",
+        "+------------------------------------------------+",
+        "| {value: 2.0, time: 1970-01-01T00:00:00.000002} |",
+        "+------------------------------------------------+",
     ];
     assert_batches_eq!(expected, &execute(&ctx, sql).await);
 }
@@ -62,7 +62,7 @@ async fn test_udf_returning_struct_sq() {
         "+-----------------+----------------------------+",
         "| sq.first[value] | sq.first[time]             |",
         "+-----------------+----------------------------+",
-        "| 2               | 1970-01-01T00:00:00.000002 |",
+        "| 2.0             | 1970-01-01T00:00:00.000002 |",
         "+-----------------+----------------------------+",
     ];
     assert_batches_eq!(expected, &execute(&ctx, sql).await);
