@@ -24,7 +24,7 @@ use crate::type_coercion::binary::binary_operator_data_type;
 use crate::{aggregate_function, function, window_function};
 use arrow::compute::can_cast_types;
 use arrow::datatypes::DataType;
-use datafusion_common::{DFField, DFSchema, DataFusionError, ExprSchema, Result};
+use datafusion_common::{Column, DFField, DFSchema, DataFusionError, ExprSchema, Result};
 
 /// trait to allow expr to typable with respect to a schema
 pub trait ExprSchemable {
@@ -56,9 +56,14 @@ impl ExprSchemable for Expr {
     /// (e.g. `[utf8] + [bool]`).
     fn get_type<S: ExprSchema>(&self, schema: &S) -> Result<DataType> {
         match self {
-            Expr::Alias(expr, _)
-            | Expr::Sort(Sort { expr, .. })
-            | Expr::Negative(expr) => expr.get_type(schema),
+            Expr::Alias(expr, name) => match &**expr {
+                Expr::Placeholder { data_type, .. } => match &data_type {
+                    None => schema.data_type(&Column::from_name(name)).cloned(),
+                    Some(dt) => Ok(dt.clone()),
+                },
+                _ => expr.get_type(schema),
+            },
+            Expr::Sort(Sort { expr, .. }) | Expr::Negative(expr) => expr.get_type(schema),
             Expr::Column(c) => Ok(schema.data_type(c)?.clone()),
             Expr::ScalarVariable(ty, _) => Ok(ty.clone()),
             Expr::Literal(l) => Ok(l.get_datatype()),
@@ -128,7 +133,9 @@ impl ExprSchemable for Expr {
             Expr::Like { .. } | Expr::ILike { .. } | Expr::SimilarTo { .. } => {
                 Ok(DataType::Boolean)
             }
-            Expr::Placeholder { data_type, .. } => Ok(data_type.clone()),
+            Expr::Placeholder { data_type, .. } => data_type.clone().ok_or_else(|| {
+                DataFusionError::Plan("Placeholder type could not be resolved".to_owned())
+            }),
             Expr::Wildcard => Err(DataFusionError::Internal(
                 "Wildcard expressions are not valid in a logical query plan".to_owned(),
             )),
@@ -234,6 +241,9 @@ impl ExprSchemable for Expr {
     }
 
     /// Returns a [arrow::datatypes::Field] compatible with this expression.
+    ///
+    /// So for example, a projected expression `col(c1) + col(c2)` is
+    /// placed in an output field **named** col("c1 + c2")
     fn to_field(&self, input_schema: &DFSchema) -> Result<DFField> {
         match self {
             Expr::Column(c) => Ok(DFField::new(
