@@ -129,17 +129,26 @@ impl JIT {
 
         // Next, declare the function to jit. Functions must be declared
         // before they can be called, or defined.
-        let id = self.module.declare_function(
-            &name,
-            Linkage::Export,
-            &self.ctx.func.signature,
-        )?;
+        let id = self
+            .module
+            .declare_function(&name, Linkage::Export, &self.ctx.func.signature)
+            .map_err(|e| {
+                DataFusionError::Internal(format!(
+                    "failed in declare the function to jit: {e:?}"
+                ))
+            })?;
 
         // Define the function to jit. This finishes compilation, although
         // there may be outstanding relocations to perform. Currently, jit
         // cannot finish relocations until all functions to be called are
         // defined. For now, we'll just finalize the function below.
-        self.module.define_function(id, &mut self.ctx)?;
+        self.module
+            .define_function(id, &mut self.ctx)
+            .map_err(|e| {
+                DataFusionError::Internal(format!(
+                    "failed in define the function to jit: {e:?}"
+                ))
+            })?;
 
         // Now that compilation is finished, we can clear out the context state.
         self.module.clear_context(&mut self.ctx);
